Fisheye: Tag fb057a8a186a7ba22edc23928222e4efd7ee8cc9 refers to a dead (removed) revision in file `Ringtoets/Integration/src/Ringtoets.Integration.Service/Merge/IAssessmentSectionProvider.cs'.
Fisheye: No comparison available. Pass `N' to diff?
Index: Ringtoets/Integration/src/Ringtoets.Integration.Service/Merge/ILoadAssessmentSectionService.cs
===================================================================
diff -u -r6dcb5e99d867d322fd3e48bc7539ba6675a92198 -rfb057a8a186a7ba22edc23928222e4efd7ee8cc9
--- Ringtoets/Integration/src/Ringtoets.Integration.Service/Merge/ILoadAssessmentSectionService.cs (.../ILoadAssessmentSectionService.cs) (revision 6dcb5e99d867d322fd3e48bc7539ba6675a92198)
+++ Ringtoets/Integration/src/Ringtoets.Integration.Service/Merge/ILoadAssessmentSectionService.cs (.../ILoadAssessmentSectionService.cs) (revision fb057a8a186a7ba22edc23928222e4efd7ee8cc9)
@@ -31,12 +31,12 @@
public interface ILoadAssessmentSectionService
{
///
- /// Loads the assessment sections from the given .
+ /// Gets the assessment sections from the given .
///
/// The file path to read the assessment sections from.
/// A collection of .
- /// Thrown when something went wrong
- /// while loading the assessment sections.
- IEnumerable LoadAssessmentSections(string filePath);
+ /// Thrown if something went wrong
+ /// when providing the assessment sections.
+ IEnumerable GetAssessmentSections(string filePath);
}
}
\ No newline at end of file
Index: Ringtoets/Integration/src/Ringtoets.Integration.Service/Merge/LoadAssessmentSectionService.cs
===================================================================
diff -u -r103777df4e37f7a8c35e7a45f9192027a119873e -rfb057a8a186a7ba22edc23928222e4efd7ee8cc9
--- Ringtoets/Integration/src/Ringtoets.Integration.Service/Merge/LoadAssessmentSectionService.cs (.../LoadAssessmentSectionService.cs) (revision 103777df4e37f7a8c35e7a45f9192027a119873e)
+++ Ringtoets/Integration/src/Ringtoets.Integration.Service/Merge/LoadAssessmentSectionService.cs (.../LoadAssessmentSectionService.cs) (revision fb057a8a186a7ba22edc23928222e4efd7ee8cc9)
@@ -31,7 +31,7 @@
///
/// Service which provides a from a file.
///
- public class LoadAssessmentSectionService : IAssessmentSectionProvider
+ public class LoadAssessmentSectionService : ILoadAssessmentSectionService
{
private readonly ILog log = LogManager.GetLogger(typeof(LoadAssessmentSectionService));
private readonly IStoreProject storage;
Index: Ringtoets/Integration/src/Ringtoets.Integration.Service/Merge/LoadAssessmentSectionsActivity.cs
===================================================================
diff -u -r103777df4e37f7a8c35e7a45f9192027a119873e -rfb057a8a186a7ba22edc23928222e4efd7ee8cc9
--- Ringtoets/Integration/src/Ringtoets.Integration.Service/Merge/LoadAssessmentSectionsActivity.cs (.../LoadAssessmentSectionsActivity.cs) (revision 103777df4e37f7a8c35e7a45f9192027a119873e)
+++ Ringtoets/Integration/src/Ringtoets.Integration.Service/Merge/LoadAssessmentSectionsActivity.cs (.../LoadAssessmentSectionsActivity.cs) (revision fb057a8a186a7ba22edc23928222e4efd7ee8cc9)
@@ -33,7 +33,7 @@
internal class LoadAssessmentSectionsActivity : Activity
{
private readonly AssessmentSectionsOwner assessmentSectionsOwner;
- private readonly IAssessmentSectionProvider assessmentSectionProvider;
+ private readonly ILoadAssessmentSectionService loadAssessmentSectionService;
private readonly string filePath;
private bool canceled;
@@ -43,23 +43,23 @@
///
/// The owner to set the retrieved collection
/// of on.
- /// The provider defining how to
+ /// The provider defining how to
/// retrieve the collection of from a file.
/// The file path to retrieve the collection of
/// from.
/// Thrown when any of the arguments is null.
public LoadAssessmentSectionsActivity(AssessmentSectionsOwner assessmentSectionsOwner,
- IAssessmentSectionProvider assessmentSectionProvider,
+ ILoadAssessmentSectionService loadAssessmentSectionService,
string filePath)
{
if (assessmentSectionsOwner == null)
{
throw new ArgumentNullException(nameof(assessmentSectionsOwner));
}
- if (assessmentSectionProvider == null)
+ if (loadAssessmentSectionService == null)
{
- throw new ArgumentNullException(nameof(assessmentSectionProvider));
+ throw new ArgumentNullException(nameof(loadAssessmentSectionService));
}
if (filePath == null)
@@ -68,15 +68,15 @@
}
this.assessmentSectionsOwner = assessmentSectionsOwner;
- this.assessmentSectionProvider = assessmentSectionProvider;
+ this.loadAssessmentSectionService = loadAssessmentSectionService;
this.filePath = filePath;
Description = Resources.LoadAssessmentSectionsActivity_Description;
}
protected override void OnRun()
{
- assessmentSectionsOwner.AssessmentSections = assessmentSectionProvider.GetAssessmentSections(filePath);
+ assessmentSectionsOwner.AssessmentSections = loadAssessmentSectionService.GetAssessmentSections(filePath);
}
protected override void OnCancel()
Index: Ringtoets/Integration/src/Ringtoets.Integration.Service/Ringtoets.Integration.Service.csproj
===================================================================
diff -u -r54acfe3f3d06742f69654d00175177a8748be42b -rfb057a8a186a7ba22edc23928222e4efd7ee8cc9
--- Ringtoets/Integration/src/Ringtoets.Integration.Service/Ringtoets.Integration.Service.csproj (.../Ringtoets.Integration.Service.csproj) (revision 54acfe3f3d06742f69654d00175177a8748be42b)
+++ Ringtoets/Integration/src/Ringtoets.Integration.Service/Ringtoets.Integration.Service.csproj (.../Ringtoets.Integration.Service.csproj) (revision fb057a8a186a7ba22edc23928222e4efd7ee8cc9)
@@ -22,7 +22,7 @@
-
+
True
Index: Ringtoets/Integration/test/Ringtoets.Integration.Service.Test/Merge/LoadAssessmentSectionServiceTest.cs
===================================================================
diff -u -r103777df4e37f7a8c35e7a45f9192027a119873e -rfb057a8a186a7ba22edc23928222e4efd7ee8cc9
--- Ringtoets/Integration/test/Ringtoets.Integration.Service.Test/Merge/LoadAssessmentSectionServiceTest.cs (.../LoadAssessmentSectionServiceTest.cs) (revision 103777df4e37f7a8c35e7a45f9192027a119873e)
+++ Ringtoets/Integration/test/Ringtoets.Integration.Service.Test/Merge/LoadAssessmentSectionServiceTest.cs (.../LoadAssessmentSectionServiceTest.cs) (revision fb057a8a186a7ba22edc23928222e4efd7ee8cc9)
@@ -57,7 +57,7 @@
var provider = new LoadAssessmentSectionService(storeProject);
// Assert
- Assert.IsInstanceOf(provider);
+ Assert.IsInstanceOf(provider);
mocks.VerifyAll();
}
Index: Ringtoets/Integration/test/Ringtoets.Integration.Service.Test/Merge/LoadAssessmentSectionsActivityFactoryTest.cs
===================================================================
diff -u -r103777df4e37f7a8c35e7a45f9192027a119873e -rfb057a8a186a7ba22edc23928222e4efd7ee8cc9
--- Ringtoets/Integration/test/Ringtoets.Integration.Service.Test/Merge/LoadAssessmentSectionsActivityFactoryTest.cs (.../LoadAssessmentSectionsActivityFactoryTest.cs) (revision 103777df4e37f7a8c35e7a45f9192027a119873e)
+++ Ringtoets/Integration/test/Ringtoets.Integration.Service.Test/Merge/LoadAssessmentSectionsActivityFactoryTest.cs (.../LoadAssessmentSectionsActivityFactoryTest.cs) (revision fb057a8a186a7ba22edc23928222e4efd7ee8cc9)
@@ -39,7 +39,7 @@
{
// Setup
var mocks = new MockRepository();
- var provider = mocks.Stub();
+ var provider = mocks.Stub();
mocks.ReplayAll();
// Call
@@ -52,7 +52,7 @@
}
[Test]
- public void CreateLoadAssessmentSectionsActivity_AssessmentSectionsProviderNull_ThrowsArgumentNullException()
+ public void CreateLoadAssessmentSectionsActivity_LoadAssessmentSectionServiceNull_ThrowsArgumentNullException()
{
// Call
TestDelegate call = () => LoadAssessmentSectionsActivityFactory.CreateLoadAssessmentSectionsActivity(new AssessmentSectionsOwner(),
@@ -61,15 +61,15 @@
// Assert
var exception = Assert.Throws(call);
- Assert.AreEqual("assessmentSectionProvider", exception.ParamName);
+ Assert.AreEqual("loadAssessmentSectionService", exception.ParamName);
}
[Test]
public void CreateLoadAssessmentSectionsActivity_FilePathNull_ThrowsArgumentNullException()
{
// Setup
var mocks = new MockRepository();
- var provider = mocks.Stub();
+ var provider = mocks.Stub();
mocks.ReplayAll();
// Call
@@ -93,7 +93,7 @@
IEnumerable expectedAssessmentSections = Enumerable.Empty();
var mocks = new MockRepository();
- var provider = mocks.Stub();
+ var provider = mocks.Stub();
provider.Expect(pr => pr.GetAssessmentSections(filePath)).Return(expectedAssessmentSections);
mocks.ReplayAll();
Index: Ringtoets/Integration/test/Ringtoets.Integration.Service.Test/Merge/LoadAssessmentSectionsActivityTest.cs
===================================================================
diff -u -r103777df4e37f7a8c35e7a45f9192027a119873e -rfb057a8a186a7ba22edc23928222e4efd7ee8cc9
--- Ringtoets/Integration/test/Ringtoets.Integration.Service.Test/Merge/LoadAssessmentSectionsActivityTest.cs (.../LoadAssessmentSectionsActivityTest.cs) (revision 103777df4e37f7a8c35e7a45f9192027a119873e)
+++ Ringtoets/Integration/test/Ringtoets.Integration.Service.Test/Merge/LoadAssessmentSectionsActivityTest.cs (.../LoadAssessmentSectionsActivityTest.cs) (revision fb057a8a186a7ba22edc23928222e4efd7ee8cc9)
@@ -40,7 +40,7 @@
{
// Setup
var mocks = new MockRepository();
- var provider = mocks.Stub();
+ var provider = mocks.Stub();
mocks.ReplayAll();
// Call
@@ -53,22 +53,22 @@
}
[Test]
- public void Constructor_ProviderNull_ThrowsArgumentNullException()
+ public void Constructor_loadAssessmentSectionServiceNull_ThrowsArgumentNullException()
{
// Call
TestDelegate call = () => new LoadAssessmentSectionsActivity(new AssessmentSectionsOwner(), null, string.Empty);
// Assert
var exception = Assert.Throws(call);
- Assert.AreEqual("assessmentSectionProvider", exception.ParamName);
+ Assert.AreEqual("loadAssessmentSectionService", exception.ParamName);
}
[Test]
public void Constructor_FilePathNull_ThrowsArgumentNullException()
{
// Setup
var mocks = new MockRepository();
- var provider = mocks.Stub();
+ var provider = mocks.Stub();
mocks.ReplayAll();
// Call
@@ -87,7 +87,7 @@
{
// Setup
var mocks = new MockRepository();
- var provider = mocks.Stub();
+ var provider = mocks.Stub();
mocks.ReplayAll();
var owner = new AssessmentSectionsOwner();
@@ -109,7 +109,7 @@
const string filePath = "File\\Path";
var mocks = new MockRepository();
- var provider = mocks.Stub();
+ var provider = mocks.Stub();
provider.Expect(p => p.GetAssessmentSections(filePath)).Return(Enumerable.Empty());
mocks.ReplayAll();
@@ -130,7 +130,7 @@
IEnumerable assessmentSections = Enumerable.Empty();
var mocks = new MockRepository();
- var provider = mocks.Stub();
+ var provider = mocks.Stub();
provider.Expect(p => p.GetAssessmentSections(null))
.IgnoreArguments()
.Return(assessmentSections);
@@ -153,7 +153,7 @@
{
// Setup
var mocks = new MockRepository();
- var provider = mocks.Stub();
+ var provider = mocks.Stub();
provider.Expect(p => p.GetAssessmentSections(null))
.IgnoreArguments()
.Throw(new AssessmentSectionProviderException());
@@ -178,7 +178,7 @@
IEnumerable assessmentSections = Enumerable.Empty();
var mocks = new MockRepository();
- var provider = mocks.Stub();
+ var provider = mocks.Stub();
provider.Expect(p => p.GetAssessmentSections(null))
.IgnoreArguments()
.Return(assessmentSections);
Index: Ringtoets/Integration/src/Ringtoets.Integration.Service/Merge/LoadAssessmentSectionsActivityFactory.cs
===================================================================
diff -u -r4d90e59f7bad864dba557b3e3d3dc90a4a17f63a -rfb057a8a186a7ba22edc23928222e4efd7ee8cc9
--- Ringtoets/Integration/src/Ringtoets.Integration.Service/Merge/LoadAssessmentSectionsActivityFactory.cs (.../LoadAssessmentSectionsActivityFactory.cs) (revision 4d90e59f7bad864dba557b3e3d3dc90a4a17f63a)
+++ Ringtoets/Integration/src/Ringtoets.Integration.Service/Merge/LoadAssessmentSectionsActivityFactory.cs (.../LoadAssessmentSectionsActivityFactory.cs) (revision fb057a8a186a7ba22edc23928222e4efd7ee8cc9)
@@ -35,34 +35,32 @@
///
/// Creates an activity to load collections of from a file.
///
/// The owner to set the retrieved collection
/// of on.
/// The provider defining how to
/// retrieve the collection of from a file.
/// The file path to retrieve the collection of
/// from.
/// The to load from a file.
/// Thrown when any of the arguments is null.
public static Activity CreateLoadAssessmentSectionsActivity(AssessmentSectionsOwner owner,
- IAssessmentSectionProvider assessmentSectionProvider,
+ ILoadAssessmentSectionService loadAssessmentSectionService,
string filePath)
{
if (owner == null)
{
throw new ArgumentNullException(nameof(owner));
}
- if (assessmentSectionProvider == null)
+ if (loadAssessmentSectionService == null)
{
- throw new ArgumentNullException(nameof(assessmentSectionProvider));
+ throw new ArgumentNullException(nameof(loadAssessmentSectionService));
}
if (filePath == null)
{
throw new ArgumentNullException(nameof(filePath));
}
- return new LoadAssessmentSectionsActivity(owner, assessmentSectionProvider, filePath);
+ return new LoadAssessmentSectionsActivity(owner, loadAssessmentSectionService, filePath);
}
}
}
@@ -35,34 +35,32 @@
/// Creates an activity to load collections of from a file.
///
- /// The owner to set the retrieved collection
- /// of on.
- /// The provider defining how to
- /// retrieve the collection of from a file.
- /// The file path to retrieve the collection of
- /// from.
+ /// The owner to set the retrieved collection of on.
+ /// The service for retrieving the collection of
+ /// from a file.
+ /// The file path to retrieve the collection of from.
/// The to load from a file.
/// Thrown when any of the arguments is null.
\ No newline at end of file